@@ -2,7 +2,7 @@ import warnings
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Type, cast
 
 import duckdb
-from sqlalchemy import pool
+from sqlalchemy import pool, text
 from sqlalchemy import types as sqltypes
 from sqlalchemy import util
 from sqlalchemy.dialects.postgresql.base import PGInspector
@@ -12,7 +12,7 @@ from sqlalchemy.engine.url import URL
 from .config import apply_config, get_core_config
 from .datatypes import register_extension_types
 
-__version__ = "0.6.6"
+__version__ = "0.6.8"
 
 if TYPE_CHECKING:
     from sqlalchemy.base import Connection
@@ -61,7 +61,7 @@ class ConnectionWrapper:
         return self
 
     def fetchmany(self, size: Optional[int] = None) -> List:
-        if hasattr(self.c, "fetchmany"):
+        if hasattr(self.__c, "fetchmany"):
             # fetchmany was only added in 0.5.0
             if size is None:
                 return self.__c.fetchmany()
@@ -159,6 +159,7 @@ class Dialect(PGDialect_psycopg2):
             # postgres type_codes (such as 701 for float) that duckdb doesn't have
             sqltypes.Numeric: sqltypes.Numeric,
             sqltypes.Interval: sqltypes.Interval,
+            sqltypes.JSON: sqltypes.JSON,
         },
     )
 
@@ -223,8 +224,10 @@ class Dialect(PGDialect_psycopg2):
         include: Optional[Any] = None,
         **kw: Any,
     ) -> Any:
-        s = "SELECT table_name FROM information_schema.tables WHERE table_type='VIEW' and table_schema=?"
-        rs = connection.execute(s, schema if schema is not None else "main")
+        s = "SELECT table_name FROM information_schema.tables WHERE table_type='VIEW' and table_schema=:schema_name"
+        rs = connection.execute(
+            text(s), {"schema_name": schema if schema is not None else "main"}
+        )
 
         return [row[0] for row in rs]
 
